@@ -1182,6 +1182,10 @@ atom_handling(current-1) :-
 	member(foobar, Atoms),
 	length(Atoms, L),
 	L > 100.			% else something is wrong!
+atom_handling(complete-1) :-
+	'$atom_completions'(stat, List),
+	length(List, Len),
+	Len > 2.
 
 
 		 /*******************************
@@ -1644,12 +1648,12 @@ gc(agc-2) :-		% not if concurrent: this is too simple.  There
 	    Margin > 0,
 	    \+ current_prolog_flag(test_concurrent, true)
 	->  garbage_collect_atoms,
-	    UpTo is Margin*2+10,
+	    UpTo is Margin*2+400,
 	    statistics(agc_gained, Gained0),
 	    forall(between(0, UpTo, X), atom_concat(foobar, X, _)),
 	    statistics(agc_gained, Gained1),
 	    Gained is Gained1 - Gained0,
-	    Gained > UpTo - 20		% might be some junk
+	    Gained > UpTo - 400		% might be some junk
 	;   true			% no atom-gc
 	).
 
